@@ -5,7 +5,7 @@ use warnings;
 use JSON::PP;
 use List::Util qw(sum min max);
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 sub new {
     my ($class, %opts) = @_;
@@ -373,6 +373,17 @@ sub run_query {
             next;
         }
 
+        # support for is_empty
+        if ($part eq 'is_empty') {
+            @next_results = map {
+                (ref $_ eq 'ARRAY' && !@$_) || (ref $_ eq 'HASH' && !%$_)
+                    ? JSON::PP::true
+                    : JSON::PP::false
+            } @results;
+            @results = @next_results;
+            next;
+        }
+
         # standard traversal
         for my $item (@results) {
             push @next_results, _traverse($item, $part);
@@ -639,7 +650,7 @@ JQ::Lite - A lightweight jq-like JSON query engine in Perl
 
 =head1 VERSION
 
-Version 0.40
+Version 0.41
 
 =head1 SYNOPSIS
 
